| Title: | Get the os info in a cross platform way |
|---|---|
| Description: | Get the os info in a cross platform way. |
| Authors: | Devin Pastoor [aut, cre] |
| Maintainer: | Devin Pastoor <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.2 |
| Built: | 2026-05-27 06:29:39 UTC |
| Source: | https://github.com/a2-ai/osinfo |
Get the os info in a cross platform way.
Maintainer: Devin Pastoor [email protected]